@@ -17,7 +17,23 @@
 #'   adorn_percentages("col") %>%
 #'   adorn_pct_formatting() %>%
 #'   adorn_ns(position = "front")
-
+#'   
+#' # Control the columns to be adorned with the ... variable selection argument
+#' # If using only the ... argument, you can use empty commas as shorthand 
+#' # to supply the default values to the preceding arguments:
+#' 
+#' cases <- data.frame(
+#'   region = c("East", "West"),
+#'   year = 2015,
+#'   recovered = c(125, 87),
+#'   died = c(13, 12)
+#' )
+#' 
+#'cases %>%
+#'  adorn_percentages("col",,recovered:died) %>%
+#'  adorn_pct_formatting(,,,recovered:died) %>%
+#'  adorn_ns(,,recovered:died)
+#'   
 adorn_ns <- function(dat, position = "rear", ns = attr(dat, "core"), ...) {
   # if input is a list, call purrr::map to recursively apply this function to each data.frame
   if (is.list(dat) && !is.data.frame(dat)) {
@@ -61,14 +77,14 @@ adorn_ns <- function(dat, position = "rear", ns = attr(dat, "core"), ...) {
 
     if (position == "rear") {
       result <- paste_matrices(dat, ns %>%
-                                 dplyr::mutate_all(as.character) %>%
-                                 dplyr::mutate_all(wrap_parens) %>%
-                                 dplyr::mutate_all(standardize_col_width))
+                                 dplyr::mutate_at(dplyr::vars(-dplyr::group_cols()), as.character) %>%
+                                 dplyr::mutate_at(dplyr::vars(-dplyr::group_cols()), wrap_parens) %>%
+                                 dplyr::mutate_at(dplyr::vars(-dplyr::group_cols()), standardize_col_width))
     } else if (position == "front") {
       result <- paste_matrices(ns, dat %>%
-                                 dplyr::mutate_all(as.character) %>%
-                                 dplyr::mutate_all(wrap_parens) %>%
-                                 dplyr::mutate_all(standardize_col_width))
+                                 dplyr::mutate_at(dplyr::vars(-dplyr::group_cols()), as.character) %>%
+                                 dplyr::mutate_at(dplyr::vars(-dplyr::group_cols()), wrap_parens) %>%
+                                 dplyr::mutate_at(dplyr::vars(-dplyr::group_cols()), standardize_col_width))
     }
     attributes(result) <- attrs
     
@@ -83,7 +99,7 @@ adorn_ns <- function(dat, position = "rear", ns = attr(dat, "core"), ...) {
       cols_to_adorn <- tidyselect::eval_select(expr, data = dat)
       dont_adorn <- setdiff(1:ncol(dat), cols_to_adorn)
     }
-    
+
     for(i in dont_adorn){
       result[[i]] <- dat[[i]]
     }
