@@ -366,6 +366,8 @@ test_that("print.tabyl prints without row numbers", {
 })
 
 test_that("the dplyr warning suggesting forcats::fct_explicit_na that is generated by a tabyl of a factor with NA values is caught ", {
+  # leaving this in as I'd want to know if it ever gets loud again, but the warning seems to be gone in 
+  # dplyr 1.0.0 and I have removed the withCallingHandlers({}) code in tabyl() that this was testing
   expect_silent(
     tabyl(factor(c("a", "b", NA)))
   )
@@ -387,6 +389,16 @@ test_that("3-way tabyl with 3rd var factor is listed in right order, #250", {
   expect_equal(names(tabyl(z, am, gear, cyl)), c("8", "6", "NA_"))
 })
 
+test_that("tabyl works with ordered 1st variable, #386", {
+  mt_ordered <- mtcars
+  mt_ordered$cyl <- ordered(mt_ordered$cyl, levels = c("4", "8", "6"))
+  
+  ordered_3way <- mt_ordered %>%
+    tabyl(cyl, gear, am)
+  expect_equal(class(ordered_3way[[1]]$cyl), c("ordered", "factor")) # 1st col in resulting tabyl
+  expect_equal(class(attr(ordered_3way[[1]], "core")$cyl), c("ordered", "factor")) # 1st col in tabyl core
+})
+
 test_that("factor ordering of columns is correct in 2-way tabyl", {
   two_factors <- data.frame(
     x = factor(c("big", "small", "medium", "small"),
@@ -413,3 +425,44 @@ test_that("empty strings converted to _emptystring", {
   )
 })
 
+test_that("3way tabyls with factors in cols 1-2 are arranged correctly, #379", {
+  
+  dat_3wayfactors <- data.frame(
+    gender = c("f", "m", "m", "f", "m"),
+    age_group = factor(
+      c("18-35", "46-55", "46-55", "36-45", ">55"),
+      levels = c("18-35", "36-45", "46-55", ">55")),
+    bmi_group = factor(
+      c("18.5 - 25", "25 - 30", "18.5 - 25", ">30", "<18.5"),
+      levels = c("<18.5", "18.5 - 25", "25 - 30", ">30")),
+    stringsAsFactors = TRUE
+    )
+  
+  tabyl_3wf <- dat_3wayfactors %>%
+    tabyl(bmi_group, age_group, gender, show_missing_levels = FALSE)
+  
+  expect_equal(names(tabyl_3wf$m), c("bmi_group", "46-55", ">55"))
+  expect_equal(tabyl_3wf$f[[1]],
+               factor(
+                 c("18.5 - 25", ">30"),
+                 levels = c("<18.5", "18.5 - 25", "25 - 30", ">30")
+               )
+  )
+})
+
+test_that("tabyl errors informatively called like tabyl(mtcars$cyl, mtcars$gear), #377", {
+  expect_error(
+    tabyl(mtcars$cyl, mtcars$am),
+    regexp = "Did you try to call tabyl on two vectors"
+  )
+  has_logicals <- data.frame(x = 1:2, y = c(TRUE, FALSE))
+  expect_error(
+    tabyl(has_logicals$x, has_logicals$y),
+    regexp = "Did you try to call tabyl on two vectors"
+  )
+  expect_type(
+    has_logicals %>%
+      tabyl(x, y),
+    "list"
+  )
+})
